###############################################################################
# Include Snippet for Makefiles
#
#    To create Cantera C++ applications from the install environment
#    include this file into your Makefile environment by putting
#    the line "include Cantera.mak" in your Makefile.
#
#  Main Variables:
#
#      CANTERA_INCLUDES = Variable containing the include path
#      CANTERA_LIBS = List of libraries to include on the link line
#
#      CANTERA_FORTRAN_LIBS = list of libraries to link for Fortran programs
#      CANTERA_FORTRAN_MODS = Directory containing the F90 .mod files
#

CANTERA_VERSION=2.0.1

###############################################################################
#        CANTERA CORE
###############################################################################

# The directory where Cantera include files may be found.
#  Include files in application programs should start with:
#     #include "cantera/thermo.h"
#     #include "cantera/kernel/HMWSoln.h"

CANTERA_CORE_INCLUDES=-I/usr/include

# Required Cantera libraries
CANTERA_CORE_LIBS=-pthread -L/usr/lib -lcantera -lctmath -lexecstream

CANTERA_CORE_LIBS_DEP = /usr/lib/libcantera.a

CANTERA_CORE_FTN=-L/usr/lib -lcantera_fortran -lcantera -lctmath -lexecstream

CANTERA_FORTRAN_MODS=/usr/include/cantera

CANTERA_FORTRAN_SYSLIBS=-lpthread -lstdc++

###############################################################################
#            BOOST
###############################################################################

CANTERA_BOOST_INCLUDES=
CANTERA_BOOST_LIBS= 

###############################################################################
#         CVODE/SUNDIALS LINKAGE
###############################################################################

CANTERA_SUNDIALS_INCLUDE=
CANTERA_SUNDIALS_LIBS= -lsundials_cvodes -lsundials_ida -lsundials_nvecserial

###############################################################################
#         BLAS LAPACK LINKAGE
###############################################################################

CANTERA_have_blas_lapack_dir=0

ifeq ($(CANTERA_have_blas_lapack_dir), 1)
CANTERA_BLAS_LAPACK_LIBS=-L
else
CANTERA_BLAS_LAPACK_LIBS=-L/usr/lib -lctlapack -lctblas
endif

###############################################################################
#       F2C USAGE
###############################################################################

CANTERA_F2C_LIBS= -lctf2c

###############################################################################
#      COMBINATIONS OF INCLUDES AND LIBS
###############################################################################

CANTERA_INCLUDES=$(CANTERA_CORE_INCLUDES) $(CANTERA_SUNDIALS_INCLUDE) \
                 $(CANTERA_BOOST_INCLUDES)

CANTERA_TOTAL_INCLUDES = $(CANTERA_INCLUDES)

# Add this into the compilation environment to identify the version number
CANTERA_DEFINES = -DCANTERA_VERSION=2.0.1

CANTERA_LIBS=$(CANTERA_CORE_LIBS) $(CANTERA_SUNDIALS_LIBS) \
             $(CANTERA_BLAS_LAPACK_LIBS) $(CANTERA_BOOST_LIBS) \
	     $(CANTERA_F2C_LIBS)

CANTERA_TOTAL_LIBS=$(CANTERA_LIBS)

CANTERA_TOTAL_LIBS_DEP= $(CANTERA_CORE_LIBS_DEP) \
                        $(CANTERA_SUNDIALS_LIBS_DEP) \
                        $(CANTERA_BLAS_LAPACK_LIBS_DEP)


CANTERA_FORTRAN_LIBS=$(CANTERA_CORE_FTN) $(CANTERA_SUNDIALS_LIBS) \
                     $(CANTERA_BLAS_LAPACK_LIBS) $(CANTERA_F2C_LIBS) \
                     $(CANTERA_BOOST_LIBS) $(CANTERA_FORTRAN_SYSLIBS)

###############################################################################
#  END
###############################################################################
